@@ -28,7 +28,7 @@ Pyramid Views
 from .core import *
 from .grids import *
 from .crud import *
-from .autocomplete import *
+from tailbone.views.autocomplete import AutocompleteView
 
 
 def home(request):
