@@ -39,6 +39,7 @@ from ...progress import SessionProgress
 
 from rattail import enum
 from rattail import batches
+from rattail.db.util import configure_session
 from ...db import Session
 from rattail.db.model import Batch
 from rattail.threads import Thread
@@ -142,6 +143,7 @@ class ExecuteBatch(View):
     def execute_batch(self, batch, progress):
         from rattail.db import Session
         session = Session()
+        configure_session(session)
         batch = session.merge(batch)
 
         if not batch.execute(progress):
@@ -165,7 +167,7 @@ class ExecuteBatch(View):
         if not batch:
             return HTTPFound(location=self.request.route_url('batches'))
 
-        progress = SessionProgress(self.request.session, 'batch.execute')
+        progress = SessionProgress(self.request, 'batch.execute')
         thread = Thread(target=self.execute_batch, args=(batch, progress))
         thread.start()
         kwargs = {
