@@ -51,6 +51,7 @@ from rattail.db.model import (
     Brand, Vendor, Department, Subdepartment, LabelProfile)
 from rattail.gpc import GPC
 from rattail.db.api import get_product_by_upc
+from rattail.db.util import configure_session
 from rattail.pod import get_image_url, get_image_path
 
 from ..db import Session
@@ -344,6 +345,7 @@ class CreateProductsBatch(ProductsGrid):
     def make_batch(self, provider, progress):
         from rattail.db import Session
         session = Session()
+        configure_session(session)
 
         self._filter_config = self.filter_config()
         self._sort_config = self.sort_config()
@@ -384,7 +386,7 @@ class CreateProductsBatch(ProductsGrid):
                             self.request.session['referer'] = self.request.current_route_url()
                             return HTTPFound(location=url)
                     
-                    progress = SessionProgress(self.request.session, 'products.batch')
+                    progress = SessionProgress(self.request, 'products.batch')
                     thread = Thread(target=self.make_batch, args=(provider, progress))
                     thread.start()
                     kwargs = {
